@@ -1,7 +1,7 @@
-# Copyright (c) 2003 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2004 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
-# $Id: Cookbook.pm,v 1.15 2003/10/30 13:56:35 gavin Exp $
+# $Id: Cookbook.pm,v 1.19 2004/04/22 14:01:01 gavin Exp $
 
 package WWW::CNic::Cookbook;
 use vars qw($VERSION);
@@ -18,6 +18,14 @@ This document provides a fairly complete explanation of how to implement basic R
 
 This document is a work in progress, if you want to see something in it that isn't, or find an error, please let us know by e-mailing C<webmaster@centralnic.com>.
 
+=head1 Test Mode
+
+The Toolkit can be told to run in I<test mode>, that is, to use a non-live copy of the database so that any changes made don't affect the live domains.
+
+To enable test mode, simply set the C<test> argument on the constructor, like so:
+
+	my $query = WWW::CNic->new(test => 1, ... );
+
 =head1 Getting a Suffix List
 
 CentralNic's range of available domain names changes occasionally and you may want to periodically update the list of domains we support. You can use the C<suffixes> command to retrieve an array containing all the domain suffixes CentralNic supports.
@@ -178,6 +186,8 @@ We recommend that you enable SSL when making registration and modification reque
 		printf("Error: %s\n", $response->error());
 	}
 
+IMPORTANT NOTE: the details you enter for the Client Handle (C<chandle>) should be the contact details of your customer.
+
 In order to make a registration transaction, you need to supply the C<username> and C<password> parameters - these correspond to your Reseller Handle's ID and password. Your password is C<crypt()>ed before it is sent to provide a minimum of security if you can't use SSL.
 
 You need to set a range of extra parameters to register a domain. These are explained below.
@@ -223,12 +233,6 @@ C<period> - the registration period for the domain name. CentralNic currently su
 
 The response object for this command has all the usual methods (as documented in L<WWW::CNic::Response>), plus the C<amount()> method, which returns the price in Sterling for the domain.
 
-=head1 Registering an Internationalised (IDN) Domain Name
-
-You can register and internationalised domain if you have been given the authority to do so. The process is exactly identical to that detailed above, but use C<register_idn> as the command. The list of additional characters allowed in IDN domain names is at L<http://toolkit.centralnic.com/doc/register_idn>.
-
-IDN method and code is provided to CentralNic under licence from Characterisation GmbH.
-
 =head1 Creating a New Handle
 
 If you are going to be registering multiple domains, you should create a new handle and use that to register the domains with, rather than supply new contact details for each registration, which will result in a new client handle being created each time.
@@ -463,7 +467,7 @@ You can use this command to retrieve a list of domains against your handle. The
 
 You can issue advance renewals for domains using this command. You simply set a C<domains> parameter to be an anonymous array of domain names. The server returns the invoice/pro forma ID and the total (in Sterling, excluding VAT) for the renewals.
 
-=head Getting Pricing Information
+=head1 Getting Pricing Information
 
 	use WWW::CNic;
 	use strict;
@@ -486,17 +490,59 @@ You can issue advance renewals for domains using this command. You simply set a
 
 This command allows you to retrieve pricing information for your reseller account. You must specify a C<type> parameter, which can be either 'C<registration>' (the default) or 'C<renewal>'.
 
-=head1 Test Mode
+=head1 Deleting a Domain Name
 
-The Toolkit can be told to run in I<test mode>, that is, to use a non-live copy of the database so that any changes made don't affect the live domains.
+	my $query = WWW::CNic->new(	use_ssl		=> 1,
+					command		=> 'delete',
+					domain		=> $domain,
+					username	=> $handle,
+					password	=> $password,
+				);
 
-To enable test mode, simply set the C<test> argument on the constructor, like so:
+	my $response = $query->execute();
 
-	my $query = WWW::CNic->new(test => 1, ... );
+	if ($response->is_success()) {
+		print "Domain has been deleted.\n";
+	} else {
+		print "Error: ".$response->error()."\n";
+	}
+
+Using this service, you can delete an unwanted domain name. However, you must supply a reason code in order for the deletion to take place. The currently available codes are listed below:
+
+	Code 	Meaning
+	R1 	Payment not received
+	R2 	Fraudulent Registration
+	R3 	Domain no longer required by registrant
+	R4 	Domain registered in error
+
+In accordance with our policy, an e-mail will be sent to the domain's Client Handle informing them that the domain has been deleted.
+
+=head1 Declining Renewal
+
+	my $query = WWW::CNic->new(	use_ssl		=> 1,
+					command		=> 'decline',
+					domain		=> $domain,
+					username	=> $handle,
+					password	=> $password,
+				);
+
+	my $response = $query->execute();
+
+	if ($response->is_success()) {
+		print "Domain will not be renewed.\n";
+	} else {
+		print "Error: ".$response->error()."\n";
+	}
+
+I<Declining renewal> means that a domain name will not be renewed when it expires - it will simply be deleted upon expiry.
+
+=head1 FEEDBACK
+
+We're always keen to find out about how people are using our Toolkit system, and we're happy to accept any comments, suggestions or problems you might have. If you want to get in touch, please e-mail L<toolkit@centralnic.com>.
 
 =head1 COPYRIGHT
 
-This module is (c) 2003 CentralNic Ltd. All rights reserved. This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is (c) 2004 CentralNic Ltd. All rights reserved. This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
@@ -504,7 +550,7 @@ This module is (c) 2003 CentralNic Ltd. All rights reserved. This module is free
 
 =item *
 
-http://toolkit.centralnic.com/
+L<http://toolkit.centralnic.com/>
 
 =item *
 
