@@ -1,11 +1,29 @@
-# Copyright (c) 2003 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2004 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
-# $Id: Whois.pm,v 1.7 2003/10/30 13:56:35 gavin Exp $
+# $Id: Whois.pm,v 1.9 2004/04/24 10:10:55 gavin Exp $
 
 package WWW::CNic::Response::Whois;
 use vars qw($VERSION);
 
+sub response {
+	my ($self, $key) = @_;
+	if (lc($key) =~ /^(c|t|b)handle$/) {
+		my $response = $self->SUPER::response($key);
+		if (ref($response) eq '') {
+			my ($name, $value) = split(/=/, $response, 2);
+			$value =~ s/^\"//g;
+			$value =~ s/\"$//g;
+			return { $name => $value };
+		} else {
+			return $response;
+		}
+	} else {
+		return $self->SUPER::response($key);
+
+	}
+}
+
 =pod
 
 =head1 NAME
@@ -30,7 +48,7 @@ This class has no additional methods than those it inherits from I<WWW::CNic::Re
 
 =head1 COPYRIGHT
 
-This module is (c) 2003 CentralNic Ltd. All rights reserved. This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This module is (c) 2004 CentralNic Ltd. All rights reserved. This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
@@ -55,4 +73,4 @@ L<WWW::CNic>
 use WWW::CNic::Response;
 @ISA = qw(WWW::CNic::Response);
 
-1;
\ No newline at end of file
+1;
